==> openshift-model-console-6.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskSummaryFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleQuickStartTaskSummaryFluent<A extends ConsoleQuickStartTaskSummaryFluent<A>> extends BaseFluent<A>{
  public ConsoleQuickStartTaskSummaryFluent() {
  }
  
  public ConsoleQuickStartTaskSummaryFluent(ConsoleQuickStartTaskSummary instance) {
    this.copyInstance(instance);
  }
  private String failed;
  private String success;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleQuickStartTaskSummary instance) {
    instance = (instance != null ? instance : new ConsoleQuickStartTaskSummary());
  
    if (instance != null) {
        this.withFailed(instance.getFailed());
        this.withSuccess(instance.getSuccess());
        this.withFailed(instance.getFailed());
        this.withSuccess(instance.getSuccess());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getFailed() {
    return this.failed;
  }
  
  public A withFailed(String failed) {
    this.failed=failed; return (A) this;
  }
  
  public boolean hasFailed() {
    return this.failed != null;
  }
  
  public String getSuccess() {
    return this.success;
  }
  
  public A withSuccess(String success) {
    this.success=success; return (A) this;
  }
  
  public boolean hasSuccess() {
    return this.success != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartTaskSummaryFluent that = (ConsoleQuickStartTaskSummaryFluent) o;
    if (!java.util.Objects.equals(failed, that.failed)) return false;
  
    if (!java.util.Objects.equals(success, that.success)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(failed,  success,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failed != null) { sb.append("failed:"); sb.append(failed + ","); }
    if (success != null) { sb.append("success:"); sb.append(success + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-console-6.9.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskSummaryFluent.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsoleQuickStartTaskSummaryFluent<A extends ConsoleQuickStartTaskSummaryFluent<A>> extends BaseFluent<A>{
  public ConsoleQuickStartTaskSummaryFluent() {
  }
  
  public ConsoleQuickStartTaskSummaryFluent(ConsoleQuickStartTaskSummary instance) {
    this.copyInstance(instance);
  }
  private String failed;
  private String success;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsoleQuickStartTaskSummary instance) {
    instance = (instance != null ? instance : new ConsoleQuickStartTaskSummary());
    if (instance != null) {
          this.withFailed(instance.getFailed());
          this.withSuccess(instance.getSuccess());
          this.withFailed(instance.getFailed());
          this.withSuccess(instance.getSuccess());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getFailed() {
    return this.failed;
  }
  
  public A withFailed(String failed) {
    this.failed = failed;
    return (A) this;
  }
  
  public boolean hasFailed() {
    return this.failed != null;
  }
  
  public String getSuccess() {
    return this.success;
  }
  
  public A withSuccess(String success) {
    this.success = success;
    return (A) this;
  }
  
  public boolean hasSuccess() {
    return this.success != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartTaskSummaryFluent that = (ConsoleQuickStartTaskSummaryFluent) o;
    if (!java.util.Objects.equals(failed, that.failed)) return false;
    if (!java.util.Objects.equals(success, that.success)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(failed,  success,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failed != null) { sb.append("failed:"); sb.append(failed + ","); }
    if (success != null) { sb.append("success:"); sb.append(success + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
